@@ -14,11 +14,11 @@ def cachedmethod(f, cache={}):
 
     def _(*args, **kwargs):
         try:
-            key = (f, tuple(args), frozenset(kwargs.items()))
+            key = hash((f, tuple(args), frozenset(kwargs.items())))
             if key not in cache:
                 cache[key] = f(*args, **kwargs)
         except:
-            key = "".join(str(_) for _ in (f, args, kwargs))
+            key = hash("".join(str(_) for _ in (f, args, kwargs)))
             if key not in cache:
                 cache[key] = f(*args, **kwargs)
 
